﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace UltraWinGridDemoApp {
  public partial class Form1 : Form {
    public Form1() {
      InitializeComponent();

      this.ultraGrid1.CellChange += ultraGrid1_CellChange;
    }

    public delegate void GridCellErrorHandler(object sender, GridCellErrorEventArgs e);

    /// <summary>
    /// Fires when an exception happens in monitored grid's CellChange event
    /// </summary>
    public event GridCellErrorHandler GridCellChangeError;

    protected virtual void OnGridCellChangeError(GridCellErrorEventArgs e) {
      if (null != GridCellChangeError) {
        GridCellChangeError(this, e);
      }
    }

    void ultraGrid1_CellChange(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) {
      // We only want data cell changes
      if (e.Cell.IsDataCell && e.Cell.Column.DataType != typeof(DateTime)) {
        try {
          // This will be the value contained in the field cast as the underlying type
          // if a cast error occurs it will throw an exception
          object o = e.Cell.EditorResolved.Value;
          // NOTE: Don't call update on rows marked isnew or they will jump from the 
          // template row to the main grid mid edit
          DataRowView associatedRowView = e.Cell.Row.ListObject as DataRowView;
          if (associatedRowView != null && !associatedRowView.IsNew) {
            e.Cell.Row.Update();
          }
        } catch (Exception exc) {
          // give client a chance to avoid custom behavior and msgbox that may not be desired
          GridCellErrorEventArgs errArgs = new GridCellErrorEventArgs(exc, e);
          OnGridCellChangeError(errArgs);

          if (!errArgs.Handled) {
            string exceptionMessage;

            if (exc.Message.Contains("System.Decimal")) {
              exceptionMessage = "This field requires a Numeric entry.";
            } else {
              exceptionMessage = exc.Message;
            }
            e.Cell.Value = e.Cell.OriginalValue;
            MessageBox.Show(exceptionMessage, "Invalid Entry",
                MessageBoxButtons.OK, MessageBoxIcon.Warning);
          }

        }
      }
    }

    protected override void OnLoad(EventArgs e) {
      base.OnLoad(e);

      this.testDataSet1.TestTable.AddTestTableRow(1, "TEST 1", "TEST DESCRIPTION");
    }
  }
}
